@@ -1,10 +1,5 @@
-
-extern crate rand;
-extern crate ndarray;
-extern crate ndarray_rand;
-
-use rand::distributions::Uniform;
 use ndarray::Array;
+use ndarray_rand::rand_distr::Uniform;
 use ndarray_rand::RandomExt;
 
 #[test]
